@@ -22,9 +22,9 @@
 #include "smartcard/readerstatus.h"
 
 #include "utils/filedialog.h"
-#include "utils/keyparameters.h"
 
 #include <Libkleo/Formatting>
+#include <Libkleo/KeyParameters>
 #include <Libkleo/KeyUsage>
 
 #include <KLocalizedString>
@@ -242,7 +242,7 @@ SaveToFileResult saveRequestToFile(const QString &filename, const QByteArray &re
 
 QUrl CreateCSRForCardKeyCommand::Private::saveRequest(const QByteArray &request)
 {
-    const QString proposedFilename = QLatin1String("request_%1.p10").arg(QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd_HHmmss")));
+    const QString proposedFilename = QLatin1StringView("request_%1.p10").arg(QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd_HHmmss")));
 
     while (true) {
         const QString filePath = FileDialog::getSaveFileNameEx(parentWidgetOrView(),
