@@ -11,8 +11,6 @@
 
 #include <crypto/gui/wizard.h>
 
-#include <utils/pimpl_ptr.h>
-
 #include <memory>
 
 namespace Kleo
@@ -54,7 +52,7 @@ private:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 
 }
