@@ -79,7 +79,7 @@ public:
             grid->addWidget(mAlgorithmCombo, row++, 1);
         }
         if (requiredAttributes & LocalKeyBackup) {
-            mBackupCheckBox = new QCheckBox(i18n("Backup encryption key"));
+            mBackupCheckBox = new QCheckBox(i18nc("@option:check", "Backup encryption key"));
             mBackupCheckBox->setToolTip(i18nc("@info:tooltip", "Backup the encryption key in a file.") + QStringLiteral("<br/>")
                                         + i18n("You will be asked for a passphrase to protect that file during key generation."));
             mBackupCheckBox->setChecked(true);
