@@ -31,7 +31,6 @@
 
 #include <KAboutData>
 #include <KConfigGroup>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
@@ -45,6 +44,8 @@
 
 using namespace Kleo;
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace
 {
 static void gpgconf_set_update_check(bool value)
@@ -181,9 +182,7 @@ UpdateNotification::UpdateNotification(QWidget *parent, const QString &version)
 
     setAttribute(Qt::WA_QuitOnClose, false);
 
-    KIconLoader *const il = KIconLoader::global();
-    const QString iconPath = il->iconPath(QStringLiteral("gpg4win"), KIconLoader::User);
-    logo->setPixmap(QIcon(iconPath).pixmap(100, 100));
+    logo->setPixmap(QPixmap{u":/gpg4win/gpg4win.png"_s}.scaled(100, 100, Qt::KeepAspectRatio, Qt::SmoothTransformation));
 
     auto label = new HtmlLabel;
     const QString boldVersion = QStringLiteral("<b>%1</b>").arg(version);
@@ -197,14 +196,14 @@ UpdateNotification::UpdateNotification(QWidget *parent, const QString &version)
 
     lay->addWidget(logo, 0, 0);
     lay->addWidget(label, 0, 1);
-    const auto chk = new QCheckBox(i18n("Show this notification for future updates."));
+    const auto chk = new QCheckBox(i18nc("@option:check", "Show this notification for future updates."));
     lay->addWidget(chk, 1, 0, 1, -1);
 
     KConfigGroup updatecfg(KSharedConfig::openConfig(), QStringLiteral("UpdateNotification"));
     chk->setChecked(!updatecfg.readEntry("NeverShow", false));
 
     const auto bb = new QDialogButtonBox();
-    const auto b = bb->addButton(i18n("&Get update"), QDialogButtonBox::AcceptRole);
+    const auto b = bb->addButton(i18nc("@action:button", "&Get update"), QDialogButtonBox::AcceptRole);
     b->setDefault(true);
     b->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
     bb->addButton(QDialogButtonBox::Cancel);
